/**
 * Copyright (c) 2009, Perforce Software, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 * 2.  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.perforce.p4http.demo.timeline;

import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.bio.SocketConnector;
import org.mortbay.jetty.servlet.Context;
import org.mortbay.jetty.servlet.DefaultServlet;
import org.mortbay.jetty.servlet.ServletHolder;

/**
 * HTTP server that generated a depot timeline in JSON
 * 
 * @author Kevin Sawicki (ksawicki@perforce.com)
 */
public class DepotTimelineServer {

    /**
     * Creates and configures a Jetty-based HTTP server with a depot timeline
     * servlet
     * 
     * @param args
     */
    public static void main(String args[]) {
	Server server = new Server();
	SocketConnector connector = new SocketConnector();
	connector.setPort(8081);
	server.setConnectors(new Connector[] { connector });

	try {
	    String base = System.getProperty("base");
	    DefaultServlet servlet = new DefaultServlet();
	    ServletHolder sHolder = new ServletHolder(servlet);
	    sHolder.setInitParameter("dirAllowed", "true");
	    sHolder.setInitParameter("resourceBase", base);
	    Context context = new Context(server, "/", Context.SESSIONS);
	    context.addServlet(sHolder, "/*");
	    context.addServlet(DepotTimelineServlet.class, "/timeline");
	    server.start();
	    server.join();
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }

}
